@@ -8,3 +8,5 @@ SYMBOLS = "symbols"
 TYPE = "type"
 ITEMS = "items"
 LIST = "List"
+VALUES = "values"
+DICT = "Dict"
